# openclip -- a python library for working with
# openclip xml files
#
# @author: Robert Moggach <rob@moggach.com>
#
# openclip/constants.py -- a place for constants.
#   constants take their value from the calling program environment
#   (if available), and default to the the expected values.
#

import os
import inspect
import sys
import errno

from . import LOG
from .internal import _MODULE_PATH

try:
    # OpenClip XML Version
    OPENCLIP_VERSION = '3'

    # OpenClip file extension
    OPENCLIP_EXT = '.clip'

    # path to test openclip xml file
    # xml extension is for github syntax highlighting only
    TEST_CLIP_PATH = os.environ.get('OPENCLIP_TEST_CLIP_PATH', os.path.join(_MODULE_PATH,'tests','test.clip'))

    # version format string
    # eg. v003 for version '3'
    OPENCLIP_VERSION_FORMAT = os.environ.get('OPENCLIP_VERSION_FORMAT', 'v{:0>3d}')

    # Set the module's path attribute
    OPENCLIP_PATH = os.environ.get('OPENCLIP_PATH', _MODULE_PATH)

    # frame number padding
    # eg. frame.0001.dpx
    MIN_FRAME_PAD = os.environ.get('OPENCLIP_MIN_FRAME_PAD', 4)

    # If we want more debugging set the OPENCLIP_DEVEL environment variable
    OPENCLIP_DEVEL = True if os.environ.get('OPENCLIP_DEVEL', False) in ['1', 'true', 'True'] else False
    LOG.debug(u'OPENCLIP_DEVEL attribute is {0}'.format(OPENCLIP_DEVEL) )

except ValueError, e:
    LOG.error(errno.EINVAL, e.message)

