from setuptools import setup, find_packages


VERSION = '0.0.1'
MODULE_DIR = 'openclip'
DESCRIPTION = "OpenClip XML Python Module {version}".format(version=VERSION)
LONG_DESCRIPTION = """\
**python-openclip** - OpenClip XML Media Management {version}
============================================================

*(c) 2016 Robert Moggach & openclip Contributors*

Licensed under the MIT license: `http://www.opensource.org/licenses/mit-license.php<http://www.opensource.org/licenses/mit-license.php>`_

OpenClip is a standalone library used to generate XML files that describe
media files. It strives to conform to the Gateway OpenClip format.
""".format(version=VERSION)


try:
   import pypandoc
   LONG_DESCRIPTION = pypandoc.convert('README.md', 'rst')
except (IOError, ImportError):
   pass


setup(
    name = "openclip",
    version = VERSION,
    description = DESCRIPTION,
    long_description = LONG_DESCRIPTION,
    scripts = [ 'scripts/oc_mkclip' ],
    packages = find_packages(),
    install_requires = [
        'lxml',
        'colorama',
        'colorlog',
        'munch',
        'parse',
        'pyseq',
        'timecode'
    ],
    package_data = {
        'openclip': ['data/openclip.*', 'tests/*.clip'],
    },
    include_package_data = True,
    # metadata for upload to PyPI
    classifiers = [
        # 'Development Status :: 1 - Planning',
        # 'Development Status :: 2 - Pre-Alpha',
        'Development Status :: 3 - Alpha',
        # 'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',
        # 'Development Status :: 6 - Mature',
        # 'Development Status :: 7 - Inactive',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Natural Language :: English',
        'Operating System :: POSIX :: Linux',
        'Operating System :: MacOS :: MacOS X',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Systems Administration',
        'Topic :: Text Processing :: Markup :: XML'
    ],
    keywords = 'filesystem media utilities vfx',
    url = 'http://github.com/robmoggach/python-openclip', # 'http://robmoggach.github.io/python-openclip/',
    download_url = 'https://github.com/robmoggach/python-openclip/tarball/v{version}'.format(version=VERSION),
    author = 'Robert Moggach',
    author_email = 'rob@moggach.com',
    maintainer = 'Robert Moggach',
    maintainer_email = 'rob@moggach.com',
    license = 'MIT License'
)
